==> nextcloud-24.0.10.tgz: nextcloud/apps/user_status/l10n/en_GB.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recent statuses",
    "In a meeting" : "In a meeting",
    "Commuting" : "Commuting",
    "Out sick" : "Out sick",
    "Vacationing" : "Vacationing",
    "Working remotely" : "Working remotely",
    "In a call" : "In a call",
    "User status" : "User status",
    "View profile" : "View profile",
    "Clear status after" : "Clear status after",
    "What is your status?" : "What is your status?",
    "Set status" : "Set status",
    "Online status" : "Online status",
    "Status message" : "Status message",
    "Clear status message" : "Clear status message",
    "Set status message" : "Set status message",
    "There was an error saving the status" : "There was an error saving the status",
    "There was an error clearing the status" : "There was an error clearing the status",
    "No recent status changes" : "No recent status changes",
    "Away" : "Away",
    "Do not disturb" : "Do not disturb",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Don't clear",
    "Today" : "Today",
    "This week" : "This week",
    "Online" : "Online",
    "Invisible" : "Invisible",
    "Offline" : "Offline",
    "There was an error saving the new status" : "There was an error saving the new status",
    "30 minutes" : "30 minutes",
    "1 hour" : "1 hour",
    "4 hours" : "4 hours",
    "Mute all notifications" : "Mute all notifications",
    "Appear offline" : "Appear offline",
    "Clear status message after" : "Clear status message after"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.7.tgz: nextcloud/apps/user_status/l10n/en_GB.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recent statuses",
    "In a meeting" : "In a meeting",
    "Commuting" : "Commuting",
    "Out sick" : "Out sick",
    "Vacationing" : "Vacationing",
    "Working remotely" : "Working remotely",
    "In a call" : "In a call",
    "User status" : "User status",
    "View profile" : "View profile",
    "Clear status after" : "Clear status after",
    "Emoji for your status message" : "Emoji for your status message",
    "What is your status?" : "What is your status?",
    "Predefined statuses" : "Predefined statuses",
    "Previously set" : "Previously set",
    "Reset status" : "Reset status",
    "Set status" : "Set status",
    "Online status" : "Online status",
    "Status message" : "Status message",
    "Your status was set automatically" : "Your status was set automatically",
    "Clear status message" : "Clear status message",
    "Set status message" : "Set status message",
    "Reset status to \"{icon} {message}\"" : "Reset status to \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Reset status to \"{message}\"",
    "Reset status to \"{icon}\"" : "Reset status to \"{icon}\"",
    "There was an error saving the status" : "There was an error saving the status",
    "There was an error clearing the status" : "There was an error clearing the status",
    "There was an error reverting the status" : "There was an error reverting the status",
    "No recent status changes" : "No recent status changes",
    "Away" : "Away",
    "Do not disturb" : "Do not disturb",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Don't clear",
    "Today" : "Today",
    "This week" : "This week",
    "Online" : "Online",
    "Invisible" : "Invisible",
    "Offline" : "Offline",
    "There was an error saving the new status" : "There was an error saving the new status",
    "30 minutes" : "30 minutes",
    "1 hour" : "1 hour",
    "4 hours" : "4 hours",
    "Mute all notifications" : "Mute all notifications",
    "Appear offline" : "Appear offline",
    "Clear status message after" : "Clear status message after"
},
"nplurals=2; plural=(n != 1);");
